@@ -27,33 +27,25 @@ from ...fields import (
 )
 from ...helpers import first_choice, get_related_object
 from ...models import FrontendUIItem
+from .. import link
 from .constants import LINK_CHOICES, LINK_SIZE_CHOICES, TARGET_CHOICES
 from .helpers import get_choices, get_object_for_value
 
+mixin_factory = settings.get_forms(link)
+
 # Weak dependency on djangocms_icon
 # (Even if djangocms_icon is in the python path, the admin form will fail due to missing
 # templates if it's not in INSTALLED_APPS)
 if "djangocms_icon" in django_settings.INSTALLED_APPS:
     from djangocms_icon.fields import IconField
 else:
+
     class IconField(forms.CharField):  # lgtm [py/missing-call-to-init]
         def __init__(self, *args, **kwargs):
             kwargs["widget"] = forms.HiddenInput
             super().__init__(*args, **kwargs)
 
 
-def get_templates():
-    choices = [
-        ("default", _("Default")),
-    ]
-    choices += getattr(
-        settings,
-        "DJANGOCMS_LINK_TEMPLATES",
-        [],
-    )
-    return choices
-
-
 HOSTNAME = getattr(settings, "DJANGOCMS_LINK_INTRANET_HOSTNAME_PATTERN", None)
 LINK_MODELS = getattr(django_settings, "DJANGOCMS_FRONTEND_LINK_MODELS", [])
 MINIMUM_INPUT_LENGTH = getattr(
@@ -298,7 +290,9 @@ else:
                         )
 
 
-class LinkForm(SpacingFormMixin, TemplateChoiceMixin, AbstractLinkForm):
+class LinkForm(
+    mixin_factory("Link"), SpacingFormMixin, TemplateChoiceMixin, AbstractLinkForm
+):
     class Meta:
         model = FrontendUIItem
         entangled_fields = {
@@ -324,8 +318,8 @@ class LinkForm(SpacingFormMixin, TemplateChoiceMixin, AbstractLinkForm):
     )
     template = forms.ChoiceField(
         label=_("Template"),
-        choices=get_templates(),
-        initial=first_choice(get_templates()),
+        choices=settings.LINK_TEMPLATE_CHOICES,
+        initial=first_choice(settings.LINK_TEMPLATE_CHOICES),
     )
     link_stretched = forms.BooleanField(
         label=_("Stretch link"),
