@@ -483,7 +483,9 @@ def t001_template(obj, new_obj, bs4_setting, dcf_setting):
     if not in_choices(obj.template, BS4):
         print(f"=> Template '{obj.template}' in {obj.plugin_type} (id: {obj.id})")
         print(f"   but not declared in {bs4_setting}")
-        print("   You will be able to edit the plugin but up saving the template will be changed.")
+        print(
+            "   You will be able to edit the plugin but up saving the template will be changed."
+        )
         if not DCF and bs4_setting != dcf_setting:
             print(f"   Remember to put {dcf_setting} in your settings.py")
 
@@ -505,15 +507,23 @@ data_migration = {
         x, y, "DJANGOCMS_PICTURE_TEMPLATES", "DJANGOCMS_PICTURE_TEMPLATES"
     ),
     "T001_LINK": lambda x, y: t001_template(
-        x, y, "DJANGOCMS_LINK_TEMPLATES", "DJANGOCMS_LINK_TEMPLATES"
+        x, y, "DJANGOCMS_LINK_TEMPLATES", "DJANGOCMS_FRONTEND_LINK_TEMPLATE_CHOICES"
     ),
     "T001_TABS": lambda x, y: t001_template(
         x, y, "DJANGOCMS_BOOTSTRAP4_TAB_TEMPLATES", "DJANGOCMS_FRONTEND_TAB_TEMPLATES"
     ),
     "T001_CAROUSEL": lambda x, y: t001_template(
-        x, y, "DJANGOCMS_BOOTSTRAP4_CAROUSEL_TEMPLATES", "DJANGOCMS_FRONTEND_CAROUSEL_TEMPLATES"
+        x,
+        y,
+        "DJANGOCMS_BOOTSTRAP4_CAROUSEL_TEMPLATES",
+        "DJANGOCMS_FRONTEND_CAROUSEL_TEMPLATES",
     ),
     "T001_CAROUSEL_SLIDE": lambda x, y: t001_template(
-        x, y, "DJANGOCMS_BOOTSTRAP4_CAROUSEL_TEMPLATES", "DJANGOCMS_FRONTEND_CAROUSEL_TEMPLATES"
+        x,
+        y,
+        "DJANGOCMS_BOOTSTRAP4_CAROUSEL_TEMPLATES",
+        "DJANGOCMS_FRONTEND_CAROUSEL_TEMPLATES",
     ),
 }
+
+plugin_prefix = "Bootstrap4"
